@@ -3,7 +3,7 @@
 '''code analysis for genes
 
 usage:
-    genecoder distance [--quiet-verbose | --quiet] [--fraction]
+    genecoder distance [--quiet-verbose | --quiet] [--fraction] [--compress ]
                        (--coder=<coder> ... | --all)
                        (--gf4=<gf4> ... | --gf4all)
                        [--output=<output>]
@@ -35,11 +35,12 @@ options:
     -c=<coder>, --coder=<coder>     add coder
     -a, --all                       add all supported codes
     -g, --graph                     draw graph
+    --compress                      output zipped csv, works with --output
     --gf4=<gf4>                     element correspondings, e.g. ATGC, ACGT
     --gf4all                        use all combinations of correspondings
     --seq=<label_na>                add 'label:nucleotide sequence'
     -i=<fasta>, --input=<fasta>     add sequences from the FASTA file
-    -o=<output>, --output=<output>  result CSV file
+    -o=<output>, --output=<output>  result CSV file (.csv or .csv.gz)
     --outdir=<outdir>               result directory
     -h, --help                      show this help
     -v, --version                   show version
@@ -63,6 +64,7 @@ import re
 import itertools
 from genecoder.resource import CODERS
 from genecoder.lab.fasta import Fasta
+from genecoder.version import VERSION
 
 
 def tune_args(args):
@@ -138,7 +140,7 @@ def validate_args(args):
 
 def main(argv=sys.argv[1:]):
     # parse argv. no options, with -v, -h will execute sys.exit()
-    args = docopt(__doc__, argv=argv, options_first=False)
+    args = docopt(__doc__, argv=argv, version='genecoder {0}'.format(VERSION), options_first=False)
 
     if __name__ == '__main__':
         print(args)
